package net.knarcraft.dynmapcitizens.formatting;

import net.knarcraft.knarlib.formatting.TranslatableMessage;

/**
 * An enum describing all of DynmapCitizens' translatable messages
 */
public enum QuestsTranslatableMessage implements TranslatableMessage {

    /**
     * The format for a quest's planner description
     *
     * <p>Placeholders: {questCoolDown}, {questFrom}, {questUntil}, {questRepeat}</p>
     */
    QUESTS_PLANNER_DESCRIPTION,

    /**
     * The format for a quest's cool-down
     *
     * <p>Placeholders: {coolDown}</p>
     */
    QUESTS_PLANNER_COOL_DOWN,

    /**
     * The text to display if a quest cannot be repeated
     */
    QUESTS_PLANNER_UNREPEATABLE,

    /**
     * The format for a quest's first availability date
     *
     * <p>Placeholders: {startDate}</p>
     */
    QUESTS_PLANNER_FROM,

    /**
     * The format for a quest's last availability date
     *
     * <p>Placeholders: {endDate}</p>
     */
    QUESTS_PLANNER_UNTIL,

    /**
     * The format for a quest's repeat delay
     *
     * <p>Placeholders: {repeatDelay}</p>
     */
    QUEST_PLANNER_REPEAT,

    /**
     * The format for a quest's requirements
     *
     * <p>Placeholders: {requirementQuestPoints}, {requirementExp}, {requirementBlockedByQuests},
     * {requirementRequiredQuests}, {requirementRequiredItems}, {requirementMCMMOSkills}, {requirementPermissions},
     * {requirementCustom}</p>
     */
    QUESTS_REQUIREMENTS_FORMAT,

    /**
     * The format for a quest's quest point requirement
     *
     * <p>Placeholders: {questPoints}</p>
     */
    QUESTS_REQUIREMENTS_QUEST_POINTS,

    /**
     * The format for a quest's exp requirement
     *
     * <p>Placeholders: {exp}</p>
     */
    QUESTS_REQUIREMENTS_EXP,

    /**
     * The format for a quest's blocking quests
     *
     * <p>Placeholders: {blockingQuests}</p>
     */
    QUESTS_REQUIREMENTS_BLOCKED_BY_QUEST_FORMAT,

    /**
     * The format for one of a quest's blocking quests
     *
     * <p>Placeholders: {questName}</p>
     */
    QUESTS_REQUIREMENTS_BLOCKED_BY_QUEST_ITEM,

    /**
     * The format for a quest's required quests
     *
     * <p>Placeholders: {requiredQuests}</p>
     */
    QUESTS_REQUIREMENTS_REQUIRED_QUEST_FORMAT,

    /**
     * The format for one of a quest's required quests
     *
     * <p>Placeholders: {questName}</p>
     */
    QUESTS_REQUIREMENTS_REQUIRED_QUEST_ITEM,

    /**
     * The format for a quest's required items
     *
     * <p>Placeholders: {requiredItems}</p>
     */
    QUESTS_REQUIREMENTS_REQUIRED_ITEM_FORMAT,

    /**
     * The format for one of a quest's required items
     *
     * <p>Placeholders: {itemName}</p>
     */
    QUESTS_REQUIREMENTS_REQUIRED_ITEM_ITEM,

    /**
     * The format for a quest's mcMMO skill requirement
     *
     * <p>Placeholders: {skill}, {level}</p>
     */
    QUESTS_REQUIREMENTS_MC_MMO_SKILL,

    /**
     * The format for a quest's required permissions
     *
     * <p>Placeholders: {permissions}</p>
     */
    QUESTS_REQUIREMENTS_REQUIRED_PERMISSION_FORMAT,

    /**
     * The format for one of a quest's required permissions
     *
     * <p>Placeholders: {permission}</p>
     */
    QUESTS_REQUIREMENTS_REQUIRED_PERMISSION_ITEM,

    /**
     * The format for a quest's reach area name
     *
     * <p>Placeholders: {name}</p>
     */
    QUESTS_REACH_AREA_NAME_FORMAT,

    /**
     * The format for a quest's reach area's description
     *
     * <p>Placeholders: {areaName}, {questName}</p>
     */
    QUESTS_REACH_AREA_DESCRIPTION_FORMAT,

    /**
     * The format for a quest's kill area name
     *
     * <p>Placeholders: {name}</p>
     */
    QUESTS_KILL_AREA_NAME_FORMAT,

    /**
     * The format for a quest's kill area description
     *
     * <p>Placeholders: {areaName}, {questName}, {mobName}, {mobAmount}</p>
     */
    QUESTS_KILL_AREA_DESCRIPTION_FORMAT,
    ;

    @Override
    public TranslatableMessage[] getAllMessages() {
        return QuestsTranslatableMessage.values();
    }
}
