package net.knarcraft.dynmapcitizens.handler;

import net.milkbowl.vault.economy.Economy;
import org.bukkit.plugin.RegisteredServiceProvider;
import org.bukkit.plugin.ServicesManager;
import org.jetbrains.annotations.NotNull;

/**
 * A class to keep track of everything Vault
 */
public class VaultHandler {

    private Economy economy = null;

    /**
     * Instantiates a new Vault handler
     *
     * @param servicesManager <p>The services manager to get the Vault service from</p>
     */
    public VaultHandler(@NotNull ServicesManager servicesManager) {
        RegisteredServiceProvider<Economy> economyProvider = servicesManager.getRegistration(Economy.class);
        if (economyProvider != null) {
            economy = economyProvider.getProvider();
        }
    }

    /**
     * Gets whether Vault is enabled
     *
     * @return <p>True if Vault is enabled</p>
     */
    public boolean isEnabled() {
        return economy != null && economy.isEnabled();
    }

    /**
     * Gets the name of the used currency
     *
     * @return <p>The currency name</p>
     */
    public @NotNull String getCurrency(boolean plural) {
        if (plural) {
            return economy.currencyNamePlural();
        } else {
            return economy.currencyNameSingular();
        }
    }

}
