package net.knarcraft.dynmapcitizens.handler.trait;

import net.citizensnpcs.api.CitizensAPI;
import net.citizensnpcs.api.npc.NPC;
import net.citizensnpcs.api.trait.Trait;
import net.knarcraft.dynmapcitizens.DynmapCitizens;
import net.knarcraft.dynmapcitizens.property.Icon;
import net.knarcraft.dynmapcitizens.settings.DTLTradersSettings;
import net.knarcraft.dynmapcitizens.settings.TraitSettings;
import org.dynmap.markers.GenericMarker;
import org.jetbrains.annotations.NotNull;

/**
 * A handler class for the minstrel trait
 */
public class DTLTradersHandler extends AbstractTraitHandler {

    private final DTLTradersSettings settings = new DTLTradersSettings();

    @Override
    public void initialize() {
        super.isEnabled = false;
        CitizensAPI.getTraitFactory().getRegisteredTraits().forEach(traitInfo -> {
            if (traitInfo.getTraitName().equals("trader")) {
                super.isEnabled = true;
            }
        });

        if (this.isEnabled) {
            super.initializeMarkerSet();
        }
    }

    @Override
    public @NotNull TraitSettings getSettings() {
        return this.settings;
    }

    @Override
    public void updateMarkers() {
        //Remove existing markers
        super.markerSet.getMarkers().forEach(GenericMarker::deleteMarker);

        Class<? extends Trait> traderTrait = CitizensAPI.getTraitFactory().getTraitClass("trader");
        for (NPC npc : CitizensAPI.getNPCRegistry()) {
            if (npc.hasTrait(traderTrait)) {
                String description = "<h2>" + npc.getName() + "</h2>";
                addNPCMarker(npc.getUniqueId(), "Trader NPC: ", description,
                        DynmapCitizens.getInstance().getGlobalSettings().getMarkerIcons().get(Icon.TRADER), super.markerSet);
            }
        }
    }

}
