package net.knarcraft.dynmapcitizens.handler.trait;

import net.citizensnpcs.api.CitizensAPI;
import net.citizensnpcs.api.npc.NPC;
import net.citizensnpcs.api.trait.Trait;
import net.knarcraft.dynmapcitizens.DynmapCitizens;
import net.knarcraft.dynmapcitizens.property.Icon;
import net.knarcraft.dynmapcitizens.settings.SentinelSettings;
import net.knarcraft.dynmapcitizens.settings.TraitSettings;
import org.bukkit.Bukkit;
import org.dynmap.markers.GenericMarker;
import org.jetbrains.annotations.NotNull;
import org.mcmonkey.sentinel.SentinelPlugin;
import org.mcmonkey.sentinel.SentinelTrait;

/**
 * A handler class for the sentinel trait
 */
public class SentinelHandler extends AbstractTraitHandler {

    protected final SentinelSettings settings = new SentinelSettings();

    @Override
    public void initialize() {
        SentinelPlugin sentinelPlugin = (SentinelPlugin) Bukkit.getServer().getPluginManager().getPlugin("Sentinel");
        if (sentinelPlugin != null) {
            super.initializeMarkerSet();
        } else {
            super.isEnabled = false;
        }
    }

    @Override
    public @NotNull TraitSettings getSettings() {
        return this.settings;
    }

    @Override
    public void updateMarkers() {
        super.markerSet.getMarkers().forEach(GenericMarker::deleteMarker);

        Class<? extends Trait> sentinelTrait = CitizensAPI.getTraitFactory().getTraitClass("sentinel");
        for (NPC npc : CitizensAPI.getNPCRegistry()) {
            if (npc.hasTrait(sentinelTrait)) {
                SentinelTrait trait = npc.getTraitNullable(SentinelTrait.class);
                String description = "<h2>" + npc.getName() + "</h2>";
                if (trait.squad != null) {
                    description += "<br><b>Squad:</b> " + trait.squad;
                }
                if (settings.displaySentinelStats()) {
                    description += "<br><b>Invincible:</b> " + trait.invincible + "<br><b>Armor:</b> " + trait.armor;
                    description += "<br><b>Health:</b> " + trait.health + "<br><b>Accuracy:</b> " + trait.accuracy;
                    description += "<br><b>Damage:</b> " + trait.damage + "<br><b>Speed:</b> " + trait.speed;
                    description += "<br><b>Allow knockback:</b> " + trait.allowKnockback;
                    description += "<br><b>Range:</b> " + trait.range + "<br><b>Reach:</b> " + trait.reach;
                    description += "<br><b>Targets:</b> " + trait.allTargets.toAllInOneString();
                    description += "<br><b>Avoids:</b> " + trait.allAvoids.toAllInOneString();
                    description += "<br><b>Ignores:</b> " + trait.allIgnores.toAllInOneString();
                }
                addNPCMarker(npc.getUniqueId(), "Sentinel NPC: ", description,
                        DynmapCitizens.getInstance().getGlobalSettings().getMarkerIcons().get(Icon.SENTINEL), super.markerSet);
            }
        }
    }

}
