package net.knarcraft.dynmapcitizens.handler.trait.quests;

import org.jetbrains.annotations.NotNull;

/**
 * A specifier for a quest NPC's main type
 */
public enum QuestNPCType {

    /**
     * An NPC responsible for giving quests
     */
    GIVER("Quest Start NPC: "),

    /**
     * An NPC killed in a quest
     */
    KILL("Quest Kill NPC: "),

    /**
     * An NPC set as the delivery target in a quest
     */
    DELIVER("Quest Deliver NPC: "),

    /**
     * An NPC to be interacted with in a quest
     */
    INTERACT("Quest Interact NPC: "),

    /**
     * An NPC which is not a quest giver, but has several tasks as part of other quests
     */
    CHAIN("Quest Chain NPC: "),
    ;

    private final String markerTitle;

    /**
     * Instantiates a new Quest NPC type
     *
     * @param markerTitle <p>The title of the marker for this type of quest NPC</p>
     */
    QuestNPCType(@NotNull String markerTitle) {
        this.markerTitle = markerTitle;
    }

    /**
     * Gets the marker title for this Quest NPC type
     *
     * @return <p>The marker title</p>
     */
    public String getMarkerTitle() {
        return this.markerTitle;
    }

}
