package net.knarcraft.dynmapcitizens.handler.trait.quests;

import me.pikamug.quests.quests.Quest;
import me.pikamug.quests.quests.components.Planner;
import net.knarcraft.dynmapcitizens.DynmapCitizens;
import net.knarcraft.knarlib.formatting.TimeFormatter;
import org.jetbrains.annotations.NotNull;

import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.Date;

/**
 * A class to generate a string containing all information about a quest's planner info
 */
public class QuestPlannerInfoGenerator {

    private final Quest quest;

    /**
     * Instantiates a new quest planner info generator
     *
     * @param quest <p>The quest to generate information about</p>
     */
    public QuestPlannerInfoGenerator(@NotNull Quest quest) {
        this.quest = quest;
    }

    /**
     * Gets information about the time-availability of a quest
     *
     * @return <p>Information about when the quest is available</p>
     */
    public @NotNull String getQuestPlannerInfo() {
        Planner planner = quest.getPlanner();
        StringBuilder plannerInfo = new StringBuilder();
        plannerInfo.append("<b>Planner:</b><ul>");

        //Quest can be repeated after a cool-down
        if (planner.hasCooldown()) {
            plannerInfo.append("<li>Quest repeatable after: ");
            plannerInfo.append(TimeFormatter.getDurationString(DynmapCitizens.getTranslator(),
                    planner.getCooldown() / 1000));
            plannerInfo.append("</li>");
        } else {
            plannerInfo.append("<li>Quest cannot be repeated!</li>");
        }

        //Quest only becomes available after the start date
        if (planner.hasStart()) {
            plannerInfo.append("<li>Quest available from ");
            plannerInfo.append(formatTimestamp(planner.getStartInMillis())).append("</li>");
        }

        //Quest is only available until the end date
        if (planner.hasEnd()) {
            plannerInfo.append("<li>Quest available until ");
            plannerInfo.append(formatTimestamp(planner.getEndInMillis())).append("</li>");
        }

        //Quest availability repeats
        if (planner.hasRepeat()) {
            plannerInfo.append("<li>Quest will become available again after ");
            plannerInfo.append(TimeFormatter.getDurationString(DynmapCitizens.getTranslator(),
                    planner.getRepeat() / 1000)).append("</li>");
        }

        plannerInfo.append("</ul>");
        return plannerInfo.toString();
    }

    /**
     * Gets a datetime string for the given timestamp
     *
     * @param timestamp <p>A timestamp in milliseconds</p>
     * @return <p>A datetime string</p>
     */
    private @NotNull String formatTimestamp(long timestamp) {
        DateFormat format = new SimpleDateFormat("dd MM yyyy HH:mm:ss");
        Date date = new Date(timestamp);
        return format.format(date);
    }

}
