package net.knarcraft.dynmapcitizens.handler.trait.quests;

import me.pikamug.quests.quests.Quest;
import me.pikamug.quests.quests.components.Rewards;
import net.knarcraft.dynmapcitizens.util.QuestsHelper;
import org.bukkit.inventory.ItemStack;
import org.jetbrains.annotations.NotNull;

/**
 * A class to generate a string containing all information about a quest's rewards
 */
public class QuestRewardsInfoGenerator {

    private final Quest quest;

    /**
     * Instantiates a new quest reward info generator
     *
     * @param quest <p>The quest to generate information about</p>
     */
    public QuestRewardsInfoGenerator(@NotNull Quest quest) {
        this.quest = quest;
    }

    /**
     * Gets information about all rewards for the given quest
     *
     * @return <p>Information about the quest's rewards</p>
     */
    public @NotNull String getQuestRewardsInfo() {
        Rewards reward = quest.getRewards();
        StringBuilder rewardInfo = new StringBuilder();
        rewardInfo.append("<b>Rewards:</b><ul>");

        if (reward.getMoney() > 0) {
            rewardInfo.append("<li>").append(reward.getMoney()).append(" ").append(QuestsHelper.getCurrency(
                    reward.getMoney())).append("</li>");
        }

        if (reward.getExp() > 0) {
            rewardInfo.append("<li>").append(reward.getExp()).append(" exp").append("</li>");
        }

        if (reward.getQuestPoints() > 0) {
            rewardInfo.append("<li>").append(reward.getQuestPoints()).append(" quest point(s)").append("</li>");
        }

        for (String permission : reward.getPermissions()) {
            rewardInfo.append("<li>").append("Permission: ").append(permission).append("</li>");
        }

        for (Object item : reward.getItems()) {
            rewardInfo.append("<li>").append(QuestsHelper.getUpperCasedItemStackString((ItemStack) item)).append("</li>");
        }

        for (String command : reward.getCommands()) {
            rewardInfo.append("<li>Command: ").append(command).append("</li>");
        }

        rewardInfo.append("</ul>");
        return rewardInfo.toString();
    }

}
