package net.knarcraft.dynmapcitizens.settings;

import org.bukkit.configuration.file.FileConfiguration;
import org.jetbrains.annotations.NotNull;

/**
 * An abstract implementation of trait settings
 */
public abstract class AbstractTraitSettings implements TraitSettings {

    private boolean isEnabled;
    private String markerSetId;
    private int markerSetPriority;
    private boolean hideMarkersByDefault;
    private String markerSetName;

    @Override
    public void load(@NotNull FileConfiguration configuration) {
        this.isEnabled = configuration.getBoolean(getTraitConfigRoot() + ".enabled", false);
        this.markerSetId = configuration.getString(getTraitConfigRoot() + ".markerSetId", null);
        this.markerSetPriority = configuration.getInt(getTraitConfigRoot() + ".markerSetPriority", 1);
        this.hideMarkersByDefault = configuration.getBoolean(getTraitConfigRoot() + ".markersHiddenByDefault", false);
        this.markerSetName = configuration.getString(getTraitConfigRoot() + ".markerSetName", null);
    }

    @Override
    public boolean isEnabled() {
        return isEnabled;
    }

    @Override
    public @NotNull String getMarkerSetId() {
        return markerSetId;
    }

    @Override
    public @NotNull String getMarkerSetName() {
        return markerSetName;
    }

    @Override
    public int getMarkerSetPriority() {
        return markerSetPriority;
    }

    @Override
    public boolean markersHiddenByDefault() {
        return hideMarkersByDefault;
    }

    /**
     * Gets the root config node for this trait's settings
     *
     * @return <p>The root config node for this trait's settings</p>
     */
    protected abstract @NotNull String getTraitConfigRoot();

}
