package net.knarcraft.dynmapcitizens.settings;

import org.bukkit.configuration.file.FileConfiguration;
import org.jetbrains.annotations.NotNull;

/**
 * All settings for the quests trait
 */
public class QuestsSettings extends AbstractTraitSettings {

    private boolean displayRewardInfo;
    private boolean displayPlannerInfo;
    private boolean displayStageInfo;
    private boolean displayRequirementInfo;
    private boolean displayUnavailableQuests;
    private final AreaMarkerSettings killAreaSettings = new AreaMarkerSettings();
    private final AreaMarkerSettings reachAreaSettings = new AreaMarkerSettings();

    @Override
    public void load(@NotNull FileConfiguration configuration) {
        super.load(configuration);
        this.displayRewardInfo = configuration.getBoolean(getTraitConfigRoot() + ".displayRewardInfo", true);
        this.displayPlannerInfo = configuration.getBoolean(getTraitConfigRoot() + ".displayPlannerInfo", true);
        this.displayStageInfo = configuration.getBoolean(getTraitConfigRoot() + ".displayStageInfo", true);
        this.displayRequirementInfo = configuration.getBoolean(getTraitConfigRoot() + ".displayRequirementInfo", true);
        this.displayUnavailableQuests = configuration.getBoolean(getTraitConfigRoot() + ".displayUnavailableQuests", true);
        this.killAreaSettings.load(configuration, getTraitConfigRoot() + ".circleMarker.killMarker");
        this.reachAreaSettings.load(configuration, getTraitConfigRoot() + ".circleMarker.reachMarker");
    }

    @Override
    protected @NotNull String getTraitConfigRoot() {
        return "traits.quests";
    }

    /**
     * Gets whether to display reward information as part of quest marker descriptions
     *
     * @return <p>True if reward information should be displayed</p>
     */
    public boolean displayRewardInfo() {
        return this.displayRewardInfo;
    }

    /**
     * Gets whether to display planner information, such as cool-down, as part of quest marker descriptions
     *
     * @return <p>True if planner information should be displayed</p>
     */
    public boolean displayPlannerInfo() {
        return this.displayPlannerInfo;
    }

    /**
     * Gets whether to display stage (task) information, as part of quest marker descriptions
     *
     * @return <p>True if stage information should be displayed</p>
     */
    public boolean displayStageInfo() {
        return this.displayStageInfo;
    }

    /**
     * Gets whether to display requirement information, as part of quest marker descriptions
     *
     * @return <p>True if reward information should be displayed</p>
     */
    public boolean displayRequirementInfo() {
        return this.displayRequirementInfo;
    }

    /**
     * Gets whether to hide quests which are currently unavailable according to the planner dates
     *
     * @return <p>True if unavailable quests should be hidden</p>
     */
    public boolean hideUnavailableQuests() {
        return !this.displayUnavailableQuests;
    }

    /**
     * Gets settings for the kill area markers
     *
     * @return <p>Settings for the kill area markers</p>
     */
    public @NotNull AreaMarkerSettings getKillAreaSettings() {
        return killAreaSettings;
    }

    /**
     * Gets settings for the reach area markers
     *
     * @return <p>Settings for the reach area markers</p>
     */
    public @NotNull AreaMarkerSettings getReachAreaSettings() {
        return reachAreaSettings;
    }

}
