package net.knarcraft.dynmapcitizens.settings;

import org.bukkit.configuration.file.FileConfiguration;
import org.jetbrains.annotations.NotNull;

/**
 * An interface describing a generic trait settings class
 */
public interface TraitSettings {

    /**
     * Loads the current values of this trait's settings from the given file configuration
     *
     * @param configuration <p>The configuration to load values from</p>
     */
    void load(@NotNull FileConfiguration configuration);

    /**
     * Gets whether this trait type is enabled in the config
     *
     * @return <p>True if this trait is enabled</p>
     */
    boolean isEnabled();

    /**
     * Gets the id of the trait's marker set
     *
     * <p>This is mainly configurable in case of duplicate ids</p>
     *
     * @return <p>The id of the marker set</p>
     */
    @NotNull String getMarkerSetId();

    /**
     * Gets the name of this trait's marker set
     *
     * @return <p>The name of the marker set</p>
     */
    @NotNull String getMarkerSetName();

    /**
     * Gets the priority of the trait's marker set
     *
     * @return <p>The priority of the marker set</p>
     */
    int getMarkerSetPriority();

    /**
     * Gets whether this trait's markers should be hidden by default
     *
     * @return <p>Whether markers should be hidden by default</p>
     */
    boolean markersHiddenByDefault();

}
